@@ -56,15 +56,15 @@ G_BEGIN_DECLS
  * [0, 255].
  */
 
-#define GNOME_CANVAS_COLOR(r, g, b) ((((int) (r) & 0xff) << 24)	\
-				     | (((int) (g) & 0xff) << 16)	\
-				     | (((int) (b) & 0xff) << 8)	\
+#define GNOME_CANVAS_COLOR(r, g, b) ((((unsigned int) (r) & 0xff) << 24)	\
+				     | (((unsigned int) (g) & 0xff) << 16)	\
+				     | (((unsigned int) (b) & 0xff) << 8)	\
 				     | 0xff)
 
-#define GNOME_CANVAS_COLOR_A(r, g, b, a) ((((int) (r) & 0xff) << 24)	\
-					  | (((int) (g) & 0xff) << 16)	\
-					  | (((int) (b) & 0xff) << 8)	\
-					  | ((int) (a) & 0xff))
+#define GNOME_CANVAS_COLOR_A(r, g, b, a) ((((unsigned int) (r) & 0xff) << 24)	\
+					  | (((unsigned int) (g) & 0xff) << 16)	\
+					  | (((unsigned int) (b) & 0xff) << 8)	\
+					  | ((unsigned int) (a) & 0xff))
 
 
 typedef struct _GnomeCanvas           GnomeCanvas;
@@ -218,28 +218,23 @@ struct _GnomeCanvasItemClass {
 	 */
 	void (* bounds) (GnomeCanvasItem *item, double *x1, double *y1, double *x2, double *y2);
 
-	/* Signal: an event ocurred for an item of this type.  The (x, y)
+	/* Signal: an event occurred for an item of this type.  The (x, y)
 	 * coordinates are in the canvas world coordinate system.
 	 */
 	gboolean (* event)                (GnomeCanvasItem *item, GdkEvent *event);
-        gboolean (* button_press_event)   (GnomeCanvasItem *item, GdkEventButton *event);
-        gboolean (* button_release_event) (GnomeCanvasItem *item, GdkEventButton *event);
-        gboolean (* motion_notify_event)  (GnomeCanvasItem *item, GdkEventMotion *event);
-        gboolean (* key_press_event)      (GnomeCanvasItem *item, GdkEventKey *event);
-        gboolean (* key_release_event)    (GnomeCanvasItem *item, GdkEventKey *event);
-        gboolean (* enter_notify_event)   (GnomeCanvasItem *item, GdkEventCrossing *event);
-        gboolean (* leave_notify_event)   (GnomeCanvasItem *item, GdkEventCrossing *event);
+
+	/* Reserved for future expansion */
+	gpointer spare_vmethods [4];
 };
 
 
-/* Standard Gtk function */
-GtkType gnome_canvas_item_get_type (void) G_GNUC_CONST;
+GType gnome_canvas_item_get_type (void) G_GNUC_CONST;
 
 /* Create a canvas item using the standard Gtk argument mechanism.  The item is
  * automatically inserted at the top of the specified canvas group.  The last
  * argument must be a NULL pointer.
  */
-GnomeCanvasItem *gnome_canvas_item_new (GnomeCanvasGroup *parent, GtkType type,
+GnomeCanvasItem *gnome_canvas_item_new (GnomeCanvasGroup *parent, GType type,
 					const gchar *first_arg_name, ...);
 
 /* Constructors for use in derived classes and language wrappers */
@@ -264,14 +259,6 @@ void gnome_canvas_item_affine_relative (GnomeCanvasItem *item, const double affi
 /* Apply an absolute affine transformation to the item. */
 void gnome_canvas_item_affine_absolute (GnomeCanvasItem *item, const double affine[6]);
 
-/* Scale an item about a point by the specified factors */
-void gnome_canvas_item_scale (GnomeCanvasItem *item,
-			      double x, double y,
-			      double scale_x, double scale_y);
-
-/* Rotate an item about a point by the specified number of degrees */
-void gnome_canvas_item_rotate (GnomeCanvasItem *item, double x, double y, double angle);
-
 /* Raise an item in the z-order of its parent group by the specified number of
  * positions.
  */
@@ -398,8 +385,7 @@ struct _GnomeCanvasGroupClass {
 };
 
 
-/* Standard Gtk function */
-GtkType gnome_canvas_group_get_type (void) G_GNUC_CONST;
+GType gnome_canvas_group_get_type (void) G_GNUC_CONST;
 
 
 /*** GnomeCanvas ***/
@@ -474,6 +460,11 @@ struct _GnomeCanvas {
 	/* Tolerance distance for picking items */
 	int close_enough;
 
+	/* Whether the canvas should center the scroll region in the middle of
+	 * the window if the scroll region is smaller than the window.
+	 */
+	unsigned int center_scroll_region : 1;
+
 	/* Whether items need update at next idle loop iteration */
 	unsigned int need_update : 1;
 
@@ -519,8 +510,7 @@ struct _GnomeCanvasClass {
 };
 
 
-/* Standard Gtk function */
-GtkType gnome_canvas_get_type (void) G_GNUC_CONST;
+GType gnome_canvas_get_type (void) G_GNUC_CONST;
 
 /* Creates a new canvas.  You should check that the canvas is created with the
  * proper visual and colormap.  Any visual will do unless you intend to insert
@@ -549,6 +539,12 @@ void gnome_canvas_set_scroll_region (GnomeCanvas *canvas,
 void gnome_canvas_get_scroll_region (GnomeCanvas *canvas,
 				     double *x1, double *y1, double *x2, double *y2);
 
+/* Whether the canvas centers the scroll region if it is smaller than the window */
+void gnome_canvas_set_center_scroll_region (GnomeCanvas *canvas, gboolean center_scroll_region);
+
+/* Returns whether the canvas is set to center the scroll region if it is smaller than the window */
+gboolean gnome_canvas_get_center_scroll_region (GnomeCanvas *canvas);
+
 /* Sets the number of pixels that correspond to one unit in world coordinates */
 void gnome_canvas_set_pixels_per_unit (GnomeCanvas *canvas, double n);
 
